==> jc-1.4.0.tar.gz: java/net/MimeTypeMapper.h <==
// class java.net.MimeTypeMapper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 662b642c7050afed java_net_MimeTypeMapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_MimeTypeMapper_H_
#define _JC_java_net_MimeTypeMapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_net_MimeTypeMapper$sub_refs	_jc_java_net_MimeTypeMapper$sub_refs;
typedef struct _jc_java_net_MimeTypeMapper$sub_nonrefs	_jc_java_net_MimeTypeMapper$sub_nonrefs;
typedef struct _jc_java_net_MimeTypeMapper$refs	_jc_java_net_MimeTypeMapper$refs;
typedef struct _jc_java_net_MimeTypeMapper$nonrefs	_jc_java_net_MimeTypeMapper$nonrefs;
typedef struct _jc_java_net_MimeTypeMapper$object	_jc_java_net_MimeTypeMapper$object;

typedef struct _jc_java_net_MimeTypeMapper$fields_struct	_jc_java_net_MimeTypeMapper$fields_struct;
typedef const struct _jc_java_net_MimeTypeMapper$vmethods	_jc_java_net_MimeTypeMapper$vmethods;
typedef const struct _jc_java_net_MimeTypeMapper$vtable	_jc_java_net_MimeTypeMapper$vtable;
typedef const struct _jc_java_net_MimeTypeMapper$vtype	_jc_java_net_MimeTypeMapper$vtype;

// Class fields structure
struct _jc_java_net_MimeTypeMapper$fields_struct {
	_jc_object_array	*mime__5fstrings;
	struct _jc_java_util_Hashtable$object	*mime__5ftypes;
};
extern _jc_java_net_MimeTypeMapper$fields_struct _jc_java_net_MimeTypeMapper$class_fields;

// Constructors
extern void _jc_java_net_MimeTypeMapper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_net_MimeTypeMapper$method$getContentTypeFor$b28fdf52e5805261(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_MimeTypeMapper$method_info$getContentTypeFor$b28fdf52e5805261;

// Static methods
extern void _jc_java_net_MimeTypeMapper$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_net_MimeTypeMapper$vmethods {
	struct _jc_java_lang_String$object	*(*getContentTypeFor$b28fdf52e5805261)(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_java_net_MimeTypeMapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_MimeTypeMapper$vmethods	java_net_MimeTypeMapper;
};

// Vtype
struct _jc_java_net_MimeTypeMapper$vtype {
	_jc_type			type;
	_jc_java_net_MimeTypeMapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_MimeTypeMapper$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_MimeTypeMapper$refs {
    _jc_java_net_MimeTypeMapper$sub_refs	java_net_MimeTypeMapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_MimeTypeMapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_MimeTypeMapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_MimeTypeMapper$sub_nonrefs	java_net_MimeTypeMapper;
};

// Object instance structure
struct _jc_java_net_MimeTypeMapper$object {
	_jc_java_net_MimeTypeMapper$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_MimeTypeMapper$vtype	*vtype;
	_jc_java_net_MimeTypeMapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_MimeTypeMapper$vtype _jc_java_net_MimeTypeMapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_MimeTypeMapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_MimeTypeMapper$class_object;

#endif	/* _JC_java_net_MimeTypeMapper_H_ */

==> jc-1.4.6.tar.gz: java/net/MimeTypeMapper.h <==
// class java.net.MimeTypeMapper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 662b642c7050afed java_net_MimeTypeMapper

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_net_MimeTypeMapper_H_
#define _JC_java_net_MimeTypeMapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_net_MimeTypeMapper$sub_refs	_jc_java_net_MimeTypeMapper$sub_refs;
typedef struct _jc_java_net_MimeTypeMapper$sub_nonrefs	_jc_java_net_MimeTypeMapper$sub_nonrefs;
typedef struct _jc_java_net_MimeTypeMapper$refs	_jc_java_net_MimeTypeMapper$refs;
typedef struct _jc_java_net_MimeTypeMapper$nonrefs	_jc_java_net_MimeTypeMapper$nonrefs;
typedef struct _jc_java_net_MimeTypeMapper$object	_jc_java_net_MimeTypeMapper$object;

typedef struct _jc_java_net_MimeTypeMapper$fields_struct	_jc_java_net_MimeTypeMapper$fields_struct;
typedef const struct _jc_java_net_MimeTypeMapper$vmethods	_jc_java_net_MimeTypeMapper$vmethods;
typedef const struct _jc_java_net_MimeTypeMapper$vtable	_jc_java_net_MimeTypeMapper$vtable;
typedef const struct _jc_java_net_MimeTypeMapper$vtype	_jc_java_net_MimeTypeMapper$vtype;

// Class fields structure
struct _jc_java_net_MimeTypeMapper$fields_struct {
	_jc_object_array	*mime__5fstrings;
	struct _jc_java_util_Hashtable$object	*mime__5ftypes;
};
extern _jc_java_net_MimeTypeMapper$fields_struct _jc_java_net_MimeTypeMapper$class_fields;

// Constructors
extern void _jc_java_net_MimeTypeMapper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_net_MimeTypeMapper$method$getContentTypeFor$b28fdf52e5805261(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_MimeTypeMapper$method_info$getContentTypeFor$b28fdf52e5805261;

// Static methods
extern void _jc_java_net_MimeTypeMapper$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_MimeTypeMapper$vmethods {
	struct _jc_java_lang_String$object	*(*getContentTypeFor$b28fdf52e5805261)(_jc_env *, struct _jc_java_net_MimeTypeMapper$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_MimeTypeMapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_MimeTypeMapper$vmethods	java_net_MimeTypeMapper;
};

// Vtype
struct _jc_java_net_MimeTypeMapper$vtype {
	_jc_type			type;
	_jc_java_net_MimeTypeMapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_MimeTypeMapper$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_MimeTypeMapper$refs {
    _jc_java_net_MimeTypeMapper$sub_refs	java_net_MimeTypeMapper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_MimeTypeMapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_MimeTypeMapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_MimeTypeMapper$sub_nonrefs	java_net_MimeTypeMapper;
};

// Object instance structure
struct _jc_java_net_MimeTypeMapper$object {
	_jc_java_net_MimeTypeMapper$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_MimeTypeMapper$vtype	*vtype;
	_jc_java_net_MimeTypeMapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_MimeTypeMapper$vtype _jc_java_net_MimeTypeMapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_MimeTypeMapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_MimeTypeMapper$class_object;

#endif	/* _JC_java_net_MimeTypeMapper_H_ */
